summaryrefslogtreecommitdiffstats
path: root/kbabel/common/kbmailer.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/common/kbmailer.h')
-rw-r--r--kbabel/common/kbmailer.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kbabel/common/kbmailer.h b/kbabel/common/kbmailer.h
index 17481636..1f35d6e2 100644
--- a/kbabel/common/kbmailer.h
+++ b/kbabel/common/kbmailer.h
@@ -21,11 +21,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -62,11 +62,11 @@ class KDE_EXPORT KBabelMailer
/**
* Constructor.
*
* @param parent The parent widget.
* @param project The project to be used.
- * @since 1.11.2 (KDE 3.5.2): @p parent parameter
+ * @since 1.11.2 (KDE 3.5.2): @p tqparent parameter
*/
- KBabelMailer( TQWidget* parent, Project::Ptr project);
+ KBabelMailer( TQWidget* tqparent, Project::Ptr project);
virtual ~KBabelMailer();
/**
@@ -91,7 +91,7 @@ class KDE_EXPORT KBabelMailer
* @param fileList contains the names of the files to be sent.
* @param initialName the possible name of the archive
*/
- void sendFiles(TQStringList fileList, const TQString& initialName = TQString::null);
+ void sendFiles(TQStringList fileList, const TQString& initialName = TQString());
/**
* Sets the the PO files' base directory.
*
@@ -109,7 +109,7 @@ class KDE_EXPORT KBabelMailer
* name is queried.
*
* @return name of the archive if it was created successfully,
- * otherwise TQString::null.
+ * otherwise TQString().
*/
TQString createArchive(TQStringList fileList, TQString initialName);
@@ -157,7 +157,7 @@ class KDE_EXPORT KBabelMailer
*/
TQString _poBaseDir;
/// The parent widget
TQWidget* m_parent;
};
@@ -62,11 +62,11 @@ class KDE_EXPORT KBabelMailer
* Constructor.
*
- * @param parent The parent widget.
+ * @param tqparent The tqparent widget.
* @param project The project to be used.
@@ -157,7 +157,7 @@ class KDE_EXPORT KBabelMailer
*/
TQString _poBaseDir;
- /// The parent widget
+ /// The tqparent widget
TQWidget* m_parent;
};